==> magic3_1.0.11_src.tar.gz: magic3/templates/ellipse/index.php <==
<?php defined( "_VALID_MOS" ) or die( "Direct Access to this location is not allowed." );$iso = split( '=', _ISO );echo '<?xml version="1.0" encoding="'. $iso[1] .'"?' .'>';?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<?php mosShowHead(); ?>
<meta http-equiv="Content-Type" content="text/html;><?php echo _ISO; ?>" />
<?php if ( $my->id ) { initEditor(); } ?>
<?php echo "<link rel=\"stylesheet\" href=\"$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/css/template_css.css\" type=\"text/css\"/>" ; ?><?php echo "<link rel=\"shortcut icon\" href=\"$GLOBALS[mosConfig_live_site]/images/favicon.ico\" />" ; ?>
</head>
<body>
<div class="all">
  <div align="center">
    <div id="container">
    	<div id="header"><img src="templates/ellipse/images/header.png" /></div>
  		<div id="navtop">
    		<div align="right">
      <?php if (mosCountModules('user3')>0) mosLoadModules('user3',0); ?>
    </div>
  </div>
  
        <div id="content">
          <table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
              <td valign="top"><div id="left">
                <?php if (mosCountModules('left')>0) mosLoadModules('left',0); ?>
</div></td>
              <td valign="top"><div id="right">
                <?php mosMainBody(); ?>
				<div id="box"><table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td><div id="latest">
      <?php if (mosCountModules('user1')>0) mosLoadModules('user1',-2); ?>
</div></td>
    <td><div id="pop">
      <?php if (mosCountModules('user2')>0) mosLoadModules('user2',-2); ?>
</div></td>
  </tr>
</table>
</div>

                <div id="banner">
                  <div align="center">
                    <?php if (mosCountModules('banner')>0) mosLoadModules('banner',0); ?>
                  </div>
                </div>
              </div></td>
            </tr>
          </table>
      </div>
	  
        <div id="contbot"><img src="templates/ellipse/images/contbot.png" /></div>
		
        <div id="footer">Powered by <a href="http://www.joomla.org">Joomla!</a> | Design by<a href="http://www.iboldesign.com"> IbolDesign</a></div>
    </div>
</div>
</div>
</body>
</html>

==> magic3_1.5.9_src.tar.gz: magic3/templates/ellipse/index.php <==
<?php defined( "_VALID_MOS" ) or die( "Direct Access to this location is not allowed." );$iso = split( '=', _ISO );echo '<?xml version="1.0" encoding="'. $iso[1] .'"?' .'>';?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<?php mosShowHead(); ?>
<meta http-equiv="Content-Type" content="text/html; <?php echo _ISO; ?>" />
<?php if ( $my->id ) { initEditor(); } ?>
<?php echo "<link rel=\"stylesheet\" href=\"$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/css/template_css.css\" type=\"text/css\"/>" ; ?><?php echo "<link rel=\"shortcut icon\" href=\"$GLOBALS[mosConfig_live_site]/images/favicon.ico\" />" ; ?>
</head>
<body>
<div class="all">
  <div align="center">
    <div id="container">
    	<div id="header"><img src="templates/ellipse/images/header.png" /></div>
  		<div id="navtop">
    		<div align="right">
      <?php if (mosCountModules('user3')>0) mosLoadModules('user3',0); ?>
    </div>
  </div>
  
        <div id="content">
          <table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
              <td valign="top"><div id="left">
                <?php if (mosCountModules('left')>0) mosLoadModules('left',0); ?>
</div></td>
              <td valign="top"><div id="right">
                <?php mosMainBody(); ?>
				<div id="box"><table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td><div id="latest">
      <?php if (mosCountModules('user1')>0) mosLoadModules('user1',-2); ?>
</div></td>
    <td><div id="pop">
      <?php if (mosCountModules('user2')>0) mosLoadModules('user2',-2); ?>
</div></td>
  </tr>
</table>
</div>

                <div id="banner">
                  <div align="center">
                    <?php if (mosCountModules('banner')>0) mosLoadModules('banner',0); ?>
                  </div>
                </div>
              </div></td>
            </tr>
          </table>
      </div>
	  
        <div id="contbot"><img src="templates/ellipse/images/contbot.png" /></div>
		
        <div id="footer">Powered by <a href="http://www.joomla.org">Joomla!</a> | Design by<a href="http://www.iboldesign.com"> IbolDesign</a></div>
    </div>
</div>
</div>
</body>
</html>
